==> apache-calcite-1.28.0-src.tar.gz: apache-calcite-1.28.0-src/core/src/main/java/org/apache/calcite/model/JsonType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

import org.checkerframework.checker.nullness.qual.Nullable;

import java.util.ArrayList;
import java.util.List;

import static java.util.Objects.requireNonNull;

/**
 * Type schema element.
 *
 * <p>Occurs within {@link JsonMapSchema#tables}.
 *
 * @see JsonRoot Description of schema elements
 */
public class JsonType {
  /** Name of this type.
   *
   * <p>Required.
   */
  public final String name;

  /** Type if this is not a struct.
   */
  public final @Nullable String type;

  /** Definition of the attributes of this type.
   */
  public final List<JsonTypeAttribute> attributes = new ArrayList<>();

  @JsonCreator
  public JsonType(
      @JsonProperty(value = "name", required = true) String name,
      @JsonProperty("type") @Nullable String type) {
    this.name = requireNonNull(name, "name");
    this.type = type;
  }

  public void accept(ModelHandler handler) {
    handler.visit(this);
  }
}

==> apache-calcite-1.37.0-src.tar.gz: apache-calcite-1.37.0-src/core/src/main/java/org/apache/calcite/model/JsonType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

import org.checkerframework.checker.nullness.qual.Nullable;

import java.util.ArrayList;
import java.util.List;

import static java.util.Objects.requireNonNull;

/**
 * Type schema element.
 *
 * <p>Occurs within {@link JsonMapSchema#types},
 * {@link JsonRoot#types}.
 *
 * @see JsonRoot Description of schema elements
 */
public class JsonType {
  /** Name of this type.
   *
   * <p>Required.
   */
  public final String name;

  /** Type if this is not a struct.
   */
  public final @Nullable String type;

  /** Definition of the attributes of this type.
   */
  public final List<JsonTypeAttribute> attributes = new ArrayList<>();

  @JsonCreator
  public JsonType(
      @JsonProperty(value = "name", required = true) String name,
      @JsonProperty("type") @Nullable String type) {
    this.name = requireNonNull(name, "name");
    this.type = type;
  }

  public void accept(ModelHandler handler) {
    handler.visit(this);
  }
}
